# Ciervo
El proposito de este reposito es entregar los codigos necesarios para realizar el procesamiento de los datos para el control de la protesis robotica. 




# TODO
- [] Utilizar redes neuronales para clasificar la marcha
- [] Implementar sistema para clasificar inicio y fin de marcha
- [] Implementar sistema de procesamiento de datos en tiempo real
    - [] Setear simulador de envio de datos
    - [] Testear nanomq en raspberry


# Notas



# Races [link](https://cybathlon.ethz.ch/documents/downloads/CYBATHLON%202024/2400318_LEG_EN.pdf)
![](assets/race/race1.png)
![](assets/race/race2.png)






